@@ -6,10 +6,12 @@ from .models import *
 
 class RiskAssignmentFilterSet(ChangeLoggedModelFilterSet):
     content_type = ContentTypeFilter()
+
     risk_id = django_filters.ModelMultipleChoiceFilter(
-        queryset=Risk.objects.all(),
+        queryset=Aduser.objects.all(),
         label='Risk (ID)',
     )
+
     relation_id = django_filters.ModelMultipleChoiceFilter(
         queryset=RiskRelation.objects.all(),
         label='Risk relation (ID)',
