@@ -1,6 +1,6 @@
 from netbox.forms import NetBoxModelForm
 from pyrsistent import v
-from .models import Risk, RiskRelation, RiskAssignment
+from .models import Aduser, RiskRelation, RiskAssignment
 from utilities.forms import (
     BootstrapMixin, DynamicModelChoiceField)
 from django import forms
@@ -8,7 +8,7 @@ from django import forms
 
 class RiskForm(NetBoxModelForm):
     class Meta:
-        model = Risk
+        model = Aduser
         fields = ('name',
                   'sAMAccountName',
                   'status',
@@ -27,7 +27,7 @@ class RiskRelationForm(NetBoxModelForm):
 
 class RiskAssignmentForm(BootstrapMixin, forms.ModelForm):
     risk = DynamicModelChoiceField(
-        queryset=Risk.objects.all()
+        queryset=Aduser.objects.all()
     )
     relation = DynamicModelChoiceField(
         queryset=RiskRelation.objects.all()
