@@ -125,7 +125,7 @@ class RiskAssignment(WebhooksMixin, ChangeLoggedModel):
         fk_field='object_id'
     )
     risk = models.ForeignKey(
-        to='users_and_computers.Risk',
+        to='users_and_computers.Aduser',
         on_delete=models.PROTECT,
         related_name='risk_assignments'
     )
