@@ -6,10 +6,10 @@ urlpatterns = (
     # risks
     path('ad_users/', views.RiskListView.as_view(), name='risk_list'),
     path('ad_users/add/', views.RiskEditView.as_view(), name='risk_add'),
-    path('ad_users/<int:pk>/', views.RiskView.as_view(), name='risk'),
+    path('ad_users/<int:pk>/', views.RiskView.as_view(), name='aduser'),
     path('ad_users/<int:pk>/edit/', views.RiskEditView.as_view(), name='risk_edit'),
     path('ad_users/<int:pk>/delete/', views.RiskDeleteView.as_view(), name='risk_delete'),
-    path('ad_users/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='risk_changelog', kwargs={ 'model': models.Risk }),
+    path('ad_users/<int:pk>/changelog/', ObjectChangeLogView.as_view(), name='risk_changelog', kwargs={ 'model': models.Aduser}),
     # risk relation
     path('riskrelation/', views.RiskRelationListView.as_view(), name='riskrelation_list'),
     path('riskrelation/add/', views.RiskRelationEditView.as_view(), name='riskrelation_add'),
